@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::SendEmail::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Git::CPAN::Patch::Command::SendEmail::VERSION = '1.1.0';
+  $Git::CPAN::Patch::Command::SendEmail::VERSION = '1.1.1';
 }
 #ABSTRACT: use C<git-send-email> to submit patches to CPAN RT
 
@@ -19,8 +19,14 @@ use MooseX::App::Command;
 with 'Git::CPAN::Patch::Role::Git';
 with 'Git::CPAN::Patch::Role::Patch';
 
+parameter extra_arg => (
+    is => 'rw',
+    isa => 'Str',
+    required => 0,
+);
+
 method run {
-    $self->send_emails($self->extra_argv);
+    $self->send_emails($self->extra_arg);
 }
 
 __PACKAGE__->meta->make_immutable;
