@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Sources::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Git::CPAN::Patch::Command::Sources::VERSION = '1.1.0';
+  $Git::CPAN::Patch::Command::Sources::VERSION = '1.1.1';
 }
 #ABSTRACT: lists sources for the module
 
@@ -55,6 +55,11 @@ option backpan => (
     documentation => 'show backpan information',
 );
 
+parameter thingy => (
+    is  => 'rw',
+    isa => 'Str',
+);
+
 has release_meta => (
     is => 'ro',
     lazy => 1,
@@ -62,7 +67,7 @@ has release_meta => (
         require MetaCPAN::API;
         my $mcpan = MetaCPAN::API->new;
 
-        my $thingy = $self->extra_argv->[0];
+        my $thingy = $self->thingy;
 
         eval { $mcpan->release( 
                 distribution => $mcpan->module($thingy)->{distribution}
@@ -97,7 +102,7 @@ method run {
     my $BackPAN_URL = "http://backpan.perl.org/";
     if ( $self->backpan ) {
         say "backpan:";
-        my $dist = $self->backpan_index->dist($self->extra_argv->[0])
+        my $dist = $self->backpan_index->dist($self->thingy)
             or die "could not find distribution on BackPAN";
 
         say "  - ", $BackPAN_URL . "/" . $_->prefix 
