@@ -3,7 +3,7 @@ BEGIN {
   $Git::CPAN::Patch::Command::Squash::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Git::CPAN::Patch::Command::Squash::VERSION = '1.1.0';
+  $Git::CPAN::Patch::Command::Squash::VERSION = '1.1.1';
 }
 #ABSTRACT: Combine multiple commits into one patch
 
@@ -19,12 +19,18 @@ use MooseX::App::Command;
 
 with 'Git::CPAN::Patch::Role::Git';
 
+has first_arg => (
+    is => 'ro',
+    isa => 'Str',
+    required => 0,
+);
+
 has branch => (
     is => 'ro',
     isa => 'Str',
     lazy => 1,
     default => method {
-        $self->extra_argv->[0] || 'patch';
+        $self->first_arg || 'patch';
     },
 );
 
